@@ -162,8 +162,9 @@ class AsyncSandbox(SandboxApi):
         timeout: Optional[int] = None,
         metadata: Optional[Dict[str, str]] = None,
         envs: Optional[Dict[str, str]] = None,
-        secure: Optional[bool] = True,
+        secure: bool = True,
         allow_internet_access: bool = True,
+        mcp: Optional[McpServer] = None,
         **opts: Unpack[ApiParams],
     ) -> Self:
         """
@@ -177,22 +178,43 @@ class AsyncSandbox(SandboxApi):
         :param envs: Custom environment variables for the sandbox
         :param secure: Envd is secured with access token and cannot be used without it, defaults to `True`.
         :param allow_internet_access: Allow sandbox to access the internet, defaults to `True`.
+        :param mcp: MCP server to enable in the sandbox
 
         :return: A Sandbox instance for the new sandbox
 
         Use this method instead of using the constructor to create a new sandbox.
         """
-        return await cls._create(
+        if not template and mcp is not None:
+            template = cls.default_mcp_template
+        elif not template:
+            template = cls.default_template
+
+        sandbox = await cls._create(
             template=template,
             timeout=timeout,
+            auto_pause=False,
             metadata=metadata,
             envs=envs,
             secure=secure,
             allow_internet_access=allow_internet_access,
-            auto_pause=False,
+            mcp=mcp,
             **opts,
         )
 
+        if mcp is not None:
+            token = str(uuid.uuid4())
+            sandbox._mcp_token = token
+
+            res = await sandbox.commands.run(
+                f"mcp-gateway --config '{json.dumps(mcp)}'",
+                user="root",
+                envs={"GATEWAY_ACCESS_TOKEN": token},
+            )
+            if res.exit_code != 0:
+                raise Exception(f"Failed to start MCP gateway: {res.stderr}")
+
+        return sandbox
+
     @overload
     async def connect(
         self,
@@ -206,6 +228,7 @@ class AsyncSandbox(SandboxApi):
         With sandbox ID you can connect to the same sandbox from different places or environments (serverless functions, etc).
 
         :param timeout: Timeout for the sandbox in **seconds**
+            For running sandboxes, the timeout will update only if the new timeout is longer than the existing one.
         :return: A running sandbox instance
 
         @example
@@ -235,6 +258,7 @@ class AsyncSandbox(SandboxApi):
 
         :param sandbox_id: Sandbox ID
         :param timeout: Timeout for the sandbox in **seconds**
+            For running sandboxes, the timeout will update only if the new timeout is longer than the existing one.
         :return: A running sandbox instance
 
         @example
@@ -261,6 +285,7 @@ class AsyncSandbox(SandboxApi):
         With sandbox ID you can connect to the same sandbox from different places or environments (serverless functions, etc).
 
         :param timeout: Timeout for the sandbox in **seconds**
+            For running sandboxes, the timeout will update only if the new timeout is longer than the existing one.
         :return: A running sandbox instance
 
         @example
@@ -272,7 +297,7 @@ class AsyncSandbox(SandboxApi):
         same_sandbox = await sandbox.connect()
         ```
         """
-        await SandboxApi._cls_resume(
+        await SandboxApi._cls_connect(
             sandbox_id=self.sandbox_id,
             timeout=timeout,
             **opts,
@@ -609,10 +634,8 @@ class AsyncSandbox(SandboxApi):
             **opts,
         )
 
-    async def beta_get_mcp_token(self) -> Optional[str]:
+    async def get_mcp_token(self) -> Optional[str]:
         """
-        [BETA] This feature is in beta and may change in the future.
-
         Get the MCP token for the sandbox.
 
         :return: MCP token for the sandbox, or None if MCP is not enabled.
@@ -630,16 +653,14 @@ class AsyncSandbox(SandboxApi):
         timeout: Optional[int] = None,
         **opts: Unpack[ApiParams],
     ) -> Self:
-        await SandboxApi._cls_resume(
+        sandbox = await SandboxApi._cls_connect(
             sandbox_id=sandbox_id,
             timeout=timeout,
             **opts,
         )
 
-        response = await SandboxApi._cls_get_info(sandbox_id, **opts)
-
         sandbox_headers = {}
-        envd_access_token = response._envd_access_token
+        envd_access_token = sandbox.envd_access_token
         if envd_access_token is not None and not isinstance(envd_access_token, Unset):
             sandbox_headers["X-Access-Token"] = envd_access_token
 
@@ -649,9 +670,9 @@ class AsyncSandbox(SandboxApi):
         )
 
         return cls(
-            sandbox_id=response.sandbox_id,
-            sandbox_domain=response.sandbox_domain,
-            envd_version=Version(response.envd_version),
+            sandbox_id=sandbox.sandbox_id,
+            sandbox_domain=sandbox.domain,
+            envd_version=Version(sandbox.envd_version),
             envd_access_token=envd_access_token,
             connection_config=connection_config,
         )
