@@ -167,6 +167,7 @@ class Sandbox(SandboxApi):
         envs: Optional[Dict[str, str]] = None,
         secure: bool = True,
         allow_internet_access: bool = True,
+        mcp: Optional[McpServer] = None,
         **opts: Unpack[ApiParams],
     ) -> Self:
         """
@@ -180,22 +181,43 @@ class Sandbox(SandboxApi):
         :param envs: Custom environment variables for the sandbox
         :param secure: Envd is secured with access token and cannot be used without it, defaults to `True`.
         :param allow_internet_access: Allow sandbox to access the internet, defaults to `True`.
+        :param mcp: MCP server to enable in the sandbox
 
         :return: A Sandbox instance for the new sandbox
 
         Use this method instead of using the constructor to create a new sandbox.
         """
-        return cls._create(
+        if not template and mcp is not None:
+            template = cls.default_mcp_template
+        elif not template:
+            template = cls.default_template
+
+        sandbox = cls._create(
             template=template,
+            auto_pause=False,
             timeout=timeout,
             metadata=metadata,
             envs=envs,
             secure=secure,
             allow_internet_access=allow_internet_access,
-            auto_pause=False,
+            mcp=mcp,
             **opts,
         )
 
+        if mcp is not None:
+            token = str(uuid.uuid4())
+            sandbox._mcp_token = token
+
+            res = sandbox.commands.run(
+                f"mcp-gateway --config '{json.dumps(mcp)}'",
+                user="root",
+                envs={"GATEWAY_ACCESS_TOKEN": token},
+            )
+            if res.exit_code != 0:
+                raise Exception(f"Failed to start MCP gateway: {res.stderr}")
+
+        return sandbox
+
     @overload
     def connect(
         self,
@@ -209,6 +231,7 @@ class Sandbox(SandboxApi):
         With sandbox ID you can connect to the same sandbox from different places or environments (serverless functions, etc).
 
         :param timeout: Timeout for the sandbox in **seconds**
+            For running sandboxes, the timeout will update only if the new timeout is longer than the existing one.
         :return: A running sandbox instance
 
         @example
@@ -238,7 +261,8 @@ class Sandbox(SandboxApi):
         With sandbox ID you can connect to the same sandbox from different places or environments (serverless functions, etc).
 
         :param sandbox_id: Sandbox ID
-        :param timeout: Timeout for the sandbox in **seconds**
+        :param timeout: Timeout for the sandbox in **seconds**.
+            For running sandboxes, the timeout will update only if the new timeout is longer than the existing one.
         :return: A running sandbox instance
 
         @example
@@ -264,7 +288,8 @@ class Sandbox(SandboxApi):
 
         With sandbox ID you can connect to the same sandbox from different places or environments (serverless functions, etc).
 
-        :param timeout: Timeout for the sandbox in **seconds**
+        :param timeout: Timeout for the sandbox in **seconds**.
+            For running sandboxes, the timeout will update only if the new timeout is longer than the existing one.
         :return: A running sandbox instance
 
         @example
@@ -276,7 +301,7 @@ class Sandbox(SandboxApi):
         same_sandbox = sandbox.connect()
         ```
         """
-        SandboxApi._cls_resume(
+        SandboxApi._cls_connect(
             sandbox_id=self.sandbox_id,
             timeout=timeout,
             **opts,
@@ -612,10 +637,8 @@ class Sandbox(SandboxApi):
             **opts,
         )
 
-    def beta_get_mcp_token(self) -> Optional[str]:
+    def get_mcp_token(self) -> Optional[str]:
         """
-        [BETA] This feature is in beta and may change in the future.
-
         Get the MCP token for the sandbox.
 
         :return: MCP token for the sandbox, or None if MCP is not enabled.
@@ -631,12 +654,10 @@ class Sandbox(SandboxApi):
         timeout: Optional[int] = None,
         **opts: Unpack[ApiParams],
     ) -> Self:
-        SandboxApi._cls_resume(sandbox_id, timeout, **opts)
-
-        response = cls._cls_get_info(sandbox_id, **opts)
+        sandbox = SandboxApi._cls_connect(sandbox_id, timeout, **opts)
 
         sandbox_headers = {}
-        envd_access_token = response._envd_access_token
+        envd_access_token = sandbox.envd_access_token
         if envd_access_token is not None and not isinstance(envd_access_token, Unset):
             sandbox_headers["X-Access-Token"] = envd_access_token
 
@@ -647,9 +668,9 @@ class Sandbox(SandboxApi):
 
         return cls(
             sandbox_id=sandbox_id,
-            sandbox_domain=response.sandbox_domain,
+            sandbox_domain=sandbox.domain,
             connection_config=connection_config,
-            envd_version=Version(response.envd_version),
+            envd_version=Version(sandbox.envd_version),
             envd_access_token=envd_access_token,
         )
 
