@@ -7,7 +7,7 @@ from httpx import Limits
 from e2b.exceptions import BuildException
 from e2b.template.consts import STACK_TRACE_DEPTH, RESOLVE_SYMLINKS
 from e2b.template.dockerfile_parser import parse_dockerfile
-from e2b.template.readycmd import ReadyCmd
+from e2b.template.readycmd import ReadyCmd, wait_for_file
 from e2b.template.types import (
     CopyItem,
     Instruction,
@@ -365,12 +365,14 @@ class TemplateBuilder:
         self,
         packages: Optional[Union[str, List[str]]] = None,
         g: Optional[bool] = False,
+        dev: Optional[bool] = False,
     ) -> "TemplateBuilder":
         """
         Install Node.js packages using npm.
 
         :param packages: Package name(s) to install. If None, installs from package.json
         :param g: Install packages globally
+        :param dev: Install packages as dev dependencies
 
         :return: `TemplateBuilder` class
 
@@ -388,6 +390,47 @@ class TemplateBuilder:
         args = ["npm", "install"]
         if g:
             args.append("-g")
+        if dev:
+            args.append("--save-dev")
+        if packages:
+            args.extend(packages)
+
+        return self._template._run_in_new_stack_trace_context(
+            lambda: self.run_cmd(" ".join(args), user="root" if g else None)
+        )
+
+    def bun_install(
+        self,
+        packages: Optional[Union[str, List[str]]] = None,
+        g: Optional[bool] = False,
+        dev: Optional[bool] = False,
+    ) -> "TemplateBuilder":
+        """
+        Install Bun packages using bun.
+
+        :param packages: Package name(s) to install. If None, installs from package.json
+        :param g: Install packages globally
+        :param dev: Install packages as dev dependencies
+
+        :return: `TemplateBuilder` class
+
+        Example
+        ```python
+        template.bun_install('express')
+        template.bun_install(['lodash', 'axios'])
+        template.bun_install('tsx', g=True)
+        template.bun_install('typescript', dev=True)
+        template.bun_install()  // Installs from package.json
+        ```
+        """
+        if isinstance(packages, str):
+            packages = [packages]
+
+        args = ["bun", "install"]
+        if g:
+            args.append("-g")
+        if dev:
+            args.append("--dev")
         if packages:
             args.extend(packages)
 
@@ -425,7 +468,7 @@ class TemplateBuilder:
             )
         )
 
-    def beta_add_mcp_server(self, servers: Union[str, List[str]]) -> "TemplateBuilder":
+    def add_mcp_server(self, servers: Union[str, List[str]]) -> "TemplateBuilder":
         """
         Install MCP servers using mcp-gateway.
 
@@ -437,8 +480,8 @@ class TemplateBuilder:
 
         Example
         ```python
-        template.beta_add_mcp_server('exa')
-        template.beta_add_mcp_server(['brave', 'firecrawl', 'duckduckgo'])
+        template.add_mcp_server('exa')
+        template.add_mcp_server(['brave', 'firecrawl', 'duckduckgo'])
         ```
         """
         if self._template._base_template != "mcp-gateway":
@@ -500,6 +543,95 @@ class TemplateBuilder:
             lambda: self.run_cmd(" ".join(args), user=user)
         )
 
+    def beta_dev_container_prebuild(
+        self,
+        devcontainer_directory: Union[str, Path],
+    ) -> "TemplateBuilder":
+        """
+        Prebuild a devcontainer from the specified directory during the build process.
+
+        :param devcontainer_directory: Path to the devcontainer directory
+
+        :return: `TemplateBuilder` class
+
+        Example
+        ```python
+        template.git_clone('https://myrepo.com/project.git', '/my-devcontainer')
+        template.beta_dev_container_prebuild('/my-devcontainer')
+        ```
+        """
+        if self._template._base_template != "devcontainer":
+            caller_frame = get_caller_frame(STACK_TRACE_DEPTH - 1)
+            stack_trace = None
+            if caller_frame is not None:
+                stack_trace = TracebackType(
+                    tb_next=None,
+                    tb_frame=caller_frame,
+                    tb_lasti=caller_frame.f_lasti,
+                    tb_lineno=caller_frame.f_lineno,
+                )
+            raise BuildException(
+                "Devcontainers can only used in the devcontainer template"
+            ).with_traceback(stack_trace)
+
+        return self._template._run_in_new_stack_trace_context(
+            lambda: self.run_cmd(
+                f"devcontainer build --workspace-folder {devcontainer_directory}",
+                user="root",
+            )
+        )
+
+    def beta_set_dev_container_start(
+        self,
+        devcontainer_directory: Union[str, Path],
+    ) -> "TemplateFinal":
+        """
+        Start a devcontainer from the specified directory and set it as the start command.
+
+        This method returns `TemplateFinal`, which means it must be the last method in the chain.
+
+        :param devcontainer_directory: Path to the devcontainer directory
+
+        :return: `TemplateFinal` class
+
+        Example
+        ```python
+        # Simple start
+        template.git_clone('https://myrepo.com/project.git', '/my-devcontainer')
+        template.beta_set_devcontainer_start('/my-devcontainer')
+
+        # With prebuild
+        template.git_clone('https://myrepo.com/project.git', '/my-devcontainer')
+        template.beta_dev_container_prebuild('/my-devcontainer')
+        template.beta_set_dev_container_start('/my-devcontainer')
+        ```
+        """
+        if self._template._base_template != "devcontainer":
+            caller_frame = get_caller_frame(STACK_TRACE_DEPTH - 1)
+            stack_trace = None
+            if caller_frame is not None:
+                stack_trace = TracebackType(
+                    tb_next=None,
+                    tb_frame=caller_frame,
+                    tb_lasti=caller_frame.f_lasti,
+                    tb_lineno=caller_frame.f_lineno,
+                )
+            raise BuildException(
+                "Devcontainers can only used in the devcontainer template"
+            ).with_traceback(stack_trace)
+
+        def _set_start():
+            return self.set_start_cmd(
+                "sudo devcontainer up --workspace-folder "
+                + devcontainer_directory
+                + " && sudo /prepare-exec.sh "
+                + devcontainer_directory
+                + " | sudo tee /devcontainer.sh > /dev/null && sudo chmod +x /devcontainer.sh && sudo touch /devcontainer.up",
+                wait_for_file("/devcontainer.up"),
+            )
+
+        return self._template._run_in_new_stack_trace_context(_set_start)
+
     def set_envs(self, envs: Dict[str, str]) -> "TemplateBuilder":
         """
         Set environment variables in the template.
@@ -835,6 +967,18 @@ class TemplateBase:
             lambda: self.from_image(f"node:{variant}")
         )
 
+    def from_bun_image(self, variant: str = "latest") -> TemplateBuilder:
+        """
+        Start template from a Bun base image.
+
+        :param variant: Bun image variant (default: 'latest')
+
+        :return: `TemplateBuilder` class
+        """
+        return self._run_in_new_stack_trace_context(
+            lambda: self.from_image(f"oven/bun:{variant}")
+        )
+
     def from_base_image(self) -> TemplateBuilder:
         """
         Start template from the E2B base image (e2bdev/base:latest).
